The code for the DeepProbLog baselines is adapted from [the official implementation](https://github.com/ML-KULeuven/deepproblog/tree/master/src/deepproblog/examples/MNIST).

First install DeepProbLog using:

```bash
pip install deepproblog
```
Then run:
```bash
python experiments/mnist_addition/deepproblog/run.py
```